const map = require('./dist/map')
const path = require('path')
const codeMap = require('./dist/code-map')

module.exports = {
  getAreaJSON (area = {type: 'country', map: 'china'}) {
    const { type, map } = area
    const baseMap = {
      country: './',
      province: './province/'
    }
    return require(`./dist/${path.join(baseMap[type], map)}`)
  },
  getMapJSON () {
    return map
  },
  getCode (area) {
    const { type, key, val } = Object.assign({
      type: 'province',
      key: 'pinyin',
      val: 'beijing'
    }, area)
    const typeMap = {
      province: 'provinces',
      city: 'cities'
    }
    const items = codeMap[typeMap[type]]
    for (let item of Object.values(items)) {
      if (item[key].startsWith(val)) {
        return item.code
      }
    }
  },
  getCodeByName (name =  '北京', type = 'province') {
    return this.getCode({ type, key: 'name', val: name})
  },
  getCodeByPy (pinyin = 'beijing', type = 'province') {
    return this.getCode({ type, key: 'pinyin', val: pinyin })
  },
  getProvince (code) {
    let provinceCode = code.substring(0, 2)
    for (let province of Object.values(map)) {
      if (province.code.startsWith(provinceCode)) {
        return province
      }
    }
  },
  getCity (code) {
    let province = this.getProvince(code)
    let cities = province.cities
    for (let city of Object.values(cities)) {
      if (city.code === code) {
        return city
      }
    }
  }
}